@@ -17,29 +17,29 @@
 # Test to make sure mdate-sh works correctly.
 
 am_create_testdir=empty
-. ./defs || Exit 1
+. ./defs || exit 1
 
 get_shell_script mdate-sh
 
-set x `./mdate-sh mdate-sh`
+set x $(./mdate-sh mdate-sh)
 shift
 echo "$*" # For debugging.
 
 # Check that mdate output looks like a date:
 test $# = 3
-case $1$3 in *[!0-9]*) Exit 1;; esac
+case $1$3 in *[!0-9]*) exit 1;; esac
 test $1 -lt 32
 # Hopefully automake will be obsolete in 80 years ;-)
-case $3 in 20[0-9][0-9]) :;; *) Exit 1;; esac
+case $3 in 20[0-9][0-9]) :;; *) exit 1;; esac
 case $2 in
   January|February|March|April|May|June|July|August) ;;
   September|October|November|December) ;;
-  *) Exit 1
+  *) exit 1
 esac
 
 # Stricter checks on the year required a POSIX date(1) command.
-if year=`date +%Y` && test $year -gt 2010; then
-  test $year = $3 || Exit 1
+if year=$(date +%Y) && test $year -gt 2010; then
+  test $year = $3 || exit 1
 fi
 
 :
