@@ -20,7 +20,7 @@
 
 . ./defs || exit 1
 
-cp "$am_testauxdir"/trivial-test-driver . \
+cp "$am_testaux_srcdir"/trivial-test-driver . \
   || fatal_ "failed to fetch auxiliary script trivial-test-driver"
 cp "$am_scriptdir"/tap-driver.pl . \
   || fatal_ "failed to fetch auxiliary script tap-driver.pl"
